Learn R Programming

admiralneuro (version 0.2.1)

admiralneuro-package: admiralneuro: Neuroscience Extension Package for ADaM in 'R' Asset Library

Description

logo

Programming neuroscience specific Clinical Data Standards Interchange Consortium (CDISC) compliant Analysis Data Model (ADaM) datasets in 'R'. ADaM datasets are a mandatory part of any New Drug or Biologics License Application submitted to the United States Food and Drug Administration (FDA). Analysis derivations are implemented in accordance with the "Analysis Data Model Implementation Guide" (CDISC Analysis Data Model Team, 2021, https://www.cdisc.org/standards/foundational/adam). This package extends the 'admiral' package.

Arguments

Author

Maintainer: Jian Wang wang_jian_wj@lilly.com (ORCID)

Authors:

  • Miles Almond (ORCID)

  • Xiao Chen (ORCID)

  • Fanny Gautier (ORCID)

  • Gayatri G.

  • Meilin Jiang (ORCID)

  • Leena Khatri (ORCID)

  • Edoardo Mancini (ORCID)

  • Eric Nantz

  • Lina Patil

  • Chris Pelentrides

Other contributors:

  • Eli Lilly and Company [copyright holder, funder]

  • Cytel Inc. [copyright holder, funder]

  • F. Hoffmann-La Roche AG [copyright holder, funder]

See Also